\name{grf}

\alias{grf}
\alias{grf.aux2}
\alias{grf.aux1}
\alias{grfclass}

%- Also NEED an `\alias' for EACH other topic documented here.

\title{Simulation of Gaussian Random Fields}

\description{
  Generates simulations of Gaussian random fields for
  given covariance parameters.
}


\usage{
grf(n, grid = "irreg", nx = round(sqrt(n)), ny = round(sqrt(n)), 
    xlims = c(0, 1), ylims = c(0, 1), nsim = 1, 
    cov.model = c("exponential", "matern", "gaussian", "spherical",
                  "circular", "cubic", "wave", "powered.exponential",
                  "cauchy", "gneiting", "gneiting.matern", "pure.nugget"),
    cov.pars = stop("covariance parameters (sigmasq and phi) needed"), 
    kappa = 0.5, nugget = 0, lambda = 1, aniso.pars,
    method = c("cholesky", "svd", "eigen", "circular.embedding"),
    messages.screen = TRUE)
}

%- maybe also `usage' for other objects documented here.

\arguments{
  \item{n}{number of points (locations) in the simulations.}
  \item{grid}{optional. A \eqn{n x 2}{n x 2} matrix with coordinates of the
    simulated data.}
  \item{nx}{optional. Number of points in the X direction.}
  \item{ny}{optional. Number of points in the X direction.}
  \item{xlims}{optional. Limits of the area in the X direction.}
  \item{ylims}{optional. Limits of the area in the Y direction.}
  \item{nsim}{Number of simulations. Defaults to 1.}
  \item{cov.model}{correlation function. See \code{\link{cov.spatial}} for
    details on the available choices of correlation functions. Defaults
    to exponential model.}
  \item{cov.pars}{a vector with 2 elements or a \eqn{n x 2} matrix with the covariance parameters
    \eqn{\sigma^2}{sigma^2} (sill)  and \eqn{\phi}{phi} (range). If a
    vetor the sill must be the first element and the range is the second. If a matrix,
    corresponding to a model with several structures, the sill values
    are placed in the first column and the range values in the second column.}
  \item{kappa}{additional parameter needed for some of the correlation
    functions , namely: \code{"matern", "powered.exponential", "gneiting"} and
    \code{"gneiting.matern"}. \cr For more details see documentation for the
    function \code{\link{cov.spatial}}.}
  \item{nugget}{The value of the nugget effect parameter \eqn{\tau^2}{tau^2}.}
  \item{lambda}{Box-Cox transformation parameter. If \eqn{\lambda = 1}{lambda = 1} no
    transformation is done, otherwise the Box-Cox data transformation is
    done before the analysis.}
  \item{aniso.pars}{geometric anisotropy parameters. By default a
    isotropic field is assumed and this argument is ignored.\cr 
    If a vector with 2 values (anisotropy angle,in radians, and
    and anisotropy ratio) is provided, the coordinates are transformed,
    the simulation is performed on the isotropic (transformed) space
    and then the coordinates are back-transformed such that the resulting
    field is anisotropic. Transformations are performed 
    by the function \code{\link{coords.aniso}}.}
  \item{method}{simulation method. Defaults to Cholesky decomposition.}
  \item{messages.screen}{a flag \code{TRUE} or \code{FALSE} indicating
    whether or not messages are printed on the screen (or output device)
    while the function is running.} 
}


\details{
  For the methods \code{"cholesky"}, \code{"svd"} and \code{"eigen"} the
  simulation consists of multiplying a vector of standardized
  normal deviates by a square root of the covariance matrix.
  The square root of a matrix is not uniquely defined. These 
  three methods differs in the way they compute the
  square root of the (positive definite) covariance matrix.

  For \code{method = "circular.embedding"} the algorithm implements
  the method described by Wood & Chan (1994) which is based on Fourier
  transforms. The algorithm for the \code{"circular.embedding"} method
  was kindly provided by Martin Schlather (Bayreuth University).
  
}


\value{
  A list with the components:
  \item{coords}{a \eqn{n x 2}{n x 2} matrix with the coordinates of the
    simulated data.}
  \item{data}{a vector (if \code{nsim = 1}) or a matrix with the
    simulations. For the latter each column corresponds to one simulation.}
  \item{cov.model}{a string with the name of the covariance model used.}
  \item{nugget}{the value of the nugget parameter.}
  \item{cov.pars}{a vector with the value of the sill and range
    parameter, respectively.}
  \item{kappa}{value of the parameter \eqn{\kappa}{kappa}.}
  \item{lambda}{value of the Box-Cox transformation parameter \eqn{\lambda}{lambda}.}
  \item{aniso.pars}{a vector with value of the anisotropy parameters (if
    provided in the input).}
  \item{method}{a string with the name of simulation method used.}
  \item{.Random.seed}{the random seed at the time the function was called.}
  \item{messages}{messages produced by the function describing the simulation.}
  \item{call}{the function call.}
}


\references{
  Wood, A.T.A. and Chan, G. (1994) Simulation of stationary Gaussian
  process in \eqn{[0,1]^d}{[0,1]^d}.
  \emph{Journal of Computatinal and Graphical Statistics}, \bold{3}, 409--432.
  
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}


\author{
  Paulo Justiniano Ribeiro Jr. \email{<paulojus@est.ufpr.br>} \cr
  Peter J. Diggle \email{<p.diggle@lancaster.ac.uk>}.
  
  Martin Schlather \email{<Martin.Schlather@uni-bayreuth.de>},
  Bayreuth University, Germany
  (\url{http://btgyn8.geo.uni-bayreuth.de/~martin/}).
}


\seealso{\code{\link{plot.grf}}, \code{\link{image.grf}},
  \code{\link{coords.aniso}}, \code{\link{chol}},
  \code{\link{svd}}, \code{\link{eigen}}.
}

\examples{
sim1 <- grf(100, cov.pars=c(1, .25))
plot(sim1)
image.grf(sim1)
#
sim2 <- grf(10201, grid="reg", cov.pars=c(10, .2), met="circ")
image.grf(sim2)

}

\keyword{spatial}
