\name{krige.conv}

\alias{krige.conv}
\alias{krige.control}
%- Also NEED an `\alias' for EACH other topic documented here.

\title{Spatial interpolation (kriging) with fixed covariance parameters}


\description{
  This function performs spatial prediction for fixed covariance
  parameters, using a global neighborhood.
  
  It can produce results which corresponds to the following kriging
  types: SK (simple kriging), OK (ordinary kriging), KTE (external trend kriging), UK (universal kriging).
  
}

\usage{
krige.conv(geodata, coords = geodata$coords, data = geodata$data, 
           locations,
           krige = krige.control(type.krige, beta = NULL,
                     trend.d, trend.l, cov.model, cov.pars,
                     kappa = 0.5, nugget = 0, micro.scale = 0,
                     dist.epsilon = 1e-10, aniso.pars = NULL, 
                     lambda = 1, signal = FALSE,
                     n.samples.backtransform = 500, n.sim = 0),
           messages.screen = TRUE) 
}

%- maybe also `usage' for other objects documented here.

\arguments{
  \item{geodata}{a list containing elements \code{$coords} and
    \code{$data} as described next. If not provided the arguments
    \code{coords} and \code{data} must be provided instead.}
  \item{coords}{a \eqn{n x 2} matrix where each row have the 2-D
    coordinates of the \eqn{n} data locations.
    By default it takes the
    element \code{$coords} of the argument \code{geodata}, if provided.}
  \item{data}{a vector with \emph{n} data values. By default it takes the
    element \code{$data} of the argument \code{geodata}, if provided.}
  \item{locations}{a \eqn{N x 2} matrix or data-frame with the 2-D
    coordinates of the \eqn{N} locations to be predicted.}
  \item{krige}{defines the model components and several options for kriging. See section DETAILS below.}
  \item{messages.screen}{a flag \code{TRUE} or \code{FALSE} indicating
    whether or not messages are printed on the screen (or output file)
    while the function is running.}
}


\details{
  Different types of kriging (SK, OK, UK, KTE)
  are performed according to how the options below are set.
  Defaults corresponds to ordinary kriging.
  
    \bold{Arguments for \code{krige = krige.control(\dots)} :} 

    \cr

    \item{type.krige}{type of kriging to be performed. Options are
      \code{"SK", "OK"} corresponding to simple or ordinary
      kriging. Kriging with external trend (universal kriging) can be
      defined setting \code{type.krige = "OK"} and specifying the
      trend model using the arguments \code{trend.d} and \code{trend.l}.} 
    \item{beta}{value of the mean (vector) parameter. Only used if \code{type.krige="SK"}.}  
    \item{trend.d}{information about the trend (covariates) values at the data
	locations. Possible values are:
	\cr
	\code{"cte"} - model with constant mean, i.e. no trend
	\cr
	\code{"1st"} - trend is defined as a first degree polynomial on the coordinates
	\cr
	\code{"2nd"} - trend is defined as a second degree polynomial on the
	coordinates
	\cr a formula of the type \code{~X}, where \code{X} is a matrix with covariates (external trend)
	at data locations.
	\cr
	Defaults to \code{"cte"}.}
    \item{trend.l}{Specifies the trend (covariate) at prediction
	locations. Must be the same type as defined in \code{trend.d}.
	Only used if prediction locations are provided in the argument
	\code{locations}.}
    \item{cov.model}{model for the correlation function. See options in the
	function call and/or documentation for the function \code{\link{cov.spatial}}.}
    \item{cov.pars}{a vector with 2 elements or a \eqn{n x 2} matrix with the covariance parameters
      \eqn{\sigma^2}{sigma^2} (sill)  and \eqn{\phi}{phi} (range). If a
      vector the sill must be the first element and the range is the second. If a matrix,
      corresponding to a model with several structures, the sill values
      are placed in the first column and the range values in the second column.}  
    \item{kappa}{additional parameter needed for some of the correlation
	functions: (\code{"matern", "powered.exponential", "gneiting"} and
	\code{"gneiting.matern"}). For more details see documentation for the
	function \code{\link{cov.spatial}}.}
    \item{nugget}{a number corresponding to the nugget variance.}
    \item{micro.scale}{micro-scale variance. If different from zero, the
    nugget variance is divided in 2 terms: \emph{micro-scale variance}
    and \emph{measurement error}. This might affect the precision of the estimates.
    In practice, these two are usually indistinguishable but it can be
    set here when possible.} 
    \item{dist.epsilon}{a value defining a distance such that points
      which are closed that this are considered co-located.}
    \item{aniso.pars}{fixed parameters for geometric anisotropy
	correction. If \code{aniso.pars = F} no correction is done otherwise
	a vector with 2 values, anisotropy angle and ratio of ranges,
	must be provided. Anisotropy correction consists of a
	transformation in the data and prediction coordinates performed
	by the function \code{\link{coords.aniso}}.}
    \item{lambda}{Box-Cox transformation parameter. If \eqn{\lambda =
	1}{lambda = 1} no transformation is used, otherwise the Box-Cox
      data transformation is performed before the analysis.
      The kriging results are returned in the same scale as the original data.
      If \eqn{\lambda = 0}{lambda = 0} the log-transformation is performed.
      If \eqn{\lambda < 0}{lambda < 0} the mean predictor doesn't make sense
      (the resulting distribution has no expectation).}
    \item{signal}{if \code{TRUE} the signal is predict, otherwise the
	variable is predict. If no transformation is performed the
	expectations are the same in both cases and the difference is only in
	the kriging variance, if nugget is different form zero.}
    \item{n.samples.backtransform}{When transformations are used
      (specified by the argument \code{lambda}), back-transformations
      are usually performed by sampling the predictive distribution and
      back-transforming the sampled values. The exceptions are for
      \eqn{\lambda = 0}{lambda = 0} (log-transformation)  and
      \eqn{\lambda = 1}{lambda = 1} (no transformation). 
      This options defines how many samples are taken to perform the
      back-transformation.}
    \item{n.sim}{optional. Number of simulations to be drawn from the
      posterior distribution. If \code{n.sim} is provided samples are
      taken from the predictive distribution. This corresponds to
      realizations or conditional (on the data) simulations.}
    
}


\value{
  A list with components:

  \item{predict}{a vector with predicted value at the prediction locations.}
  \item{krige.var}{a vector with predicted variances at the prediction locations.}
  \item{beta.est}{estimates of the \eqn{\beta}{beta} parameter
    implicitly done during the kriging procedure. Not used if
    \code{type.krige = \"SK\"}.}
  \item{simulations}{a matrix \eqn{ni x n.sim} where \eqn{ni} is the
    number of prediction locations. Each column corresponds to a simulations of the predictive distribution
    (conditional simulation). Only returned if \code{n.sim > 0}.}
  \item{message}{messages about the type of prediction performed.}
  \item{call}{stores the function call.}

}


\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

%\note{}

\author{
  Paulo J. Ribeiro Jr. <\email{paulojus@est.ufpr.br}> \cr
  Peter J. Diggle <\email{p.diggle@lancaster.ac.uk}>.
}

\seealso{\code{\link{image.kriging}}, \code{\link{krige.bayes}}, \code{\link{ksline}}.
}


\examples{

data(s100)
loci <- expand.grid(seq(0,1,l=31), seq(0,1,l=31))
kc <- krige.conv(s100, loc=loci, krige=krige.control(cov.pars=c(1, .25)))
par(mfrow=c(1,2))
image.kriging(kc, loc=loci, main="kriging estimates")
image.kriging(kc, loc=loci, val=sqrt(kc$krige.var), main="kriging std. errors")


}


\keyword{spatial}




